@@ -177,6 +177,22 @@ SEXP d2mpfr1_list(SEXP x, SEXP prec, SEXP rnd_mode)
     return val;
 }
 
+/*
+  -- Function: int mpfr_set_z (mpfr_t ROP, mpz_t OP, mpfr_rnd_t RND)
+  -- Function: int mpfr_set_q (mpfr_t ROP, mpq_t OP, mpfr_rnd_t RND)
+
+--> would want functions
+        SEXP mpz2mpfr1_(mpz_t x, int i_prec, mp_rnd_t rnd);
+	SEXP mpz2mpfr1 (SEXP x, SEXP prec, SEXP rnd_mode);
+	SEXP mpz2mpfr1_list(SEXP x, SEXP prec, SEXP rnd_mode);
+
+   completely parallel to the d2mpfr*() functions above
+   *BUT* we cannot easily do the [R package gmp C++ code]-part of
+   SEXP -> mpz !
+*/
+
+
+
 /* From the MPFR (2.3.2, 2008) doc :
  -- Function:
 
@@ -189,7 +205,6 @@ SEXP d2mpfr1_list(SEXP x, SEXP prec, SEXP rnd_mode)
      valid number in base BASE; otherwise it returns -1, and ROP may
      have changed.
 */
-
 SEXP str2mpfr1_list(SEXP x, SEXP prec, SEXP base, SEXP rnd_mode)
 {
 /* NB: Both x and prec are "recycled" to the longer one if needed */
@@ -437,10 +452,12 @@ SEXP mpfr2str(SEXP x, SEXP digits) {
 	if(n_dig) {/* use it as desired precision */
 	    dig_needed = n_dig;
 	} else { /* n_dig = 0 --> string will use "enough" digits */
-	    dig_n_max = dig_needed = p_fact * (int)R_i->_mpfr_prec;
+	    dig_needed = p_fact * (int)R_i->_mpfr_prec;
 	}
-	if (i == 0) /* first time */
+	if (i == 0) { /* first time */
+	    dig_n_max = dig_needed;
 	    ch = (char *) R_alloc(dig_needed + 2, sizeof(char));
+	}
 	else if(!n_dig && dig_needed > dig_n_max) {
 	    ch = (char *) S_realloc(ch, dig_needed + 2, dig_n_max + 2,
 				    sizeof(char));
